.. _spkg_sagemath_standard_no_symbolics:

==============================================================================================================
sagemath_standard_no_symbolics: Sage library without the symbolics subsystem
==============================================================================================================


This pip-installable distribution ``passagemath-standard-no-symbolics`` is a distribution of a part of the Sage Library.

Its main purpose is as a technical tool for the modularization project, to test that large parts of the Sage library are independent of the symbolics subsystem.


Type
----

standard


Dependencies
------------

- $(BLAS)
- $(MP_LIBRARY)
- $(PCFILES)
- $(PYTHON)
- $(PYTHON_TOOLCHAIN)
- $(SCRIPTS)
- :ref:`spkg_boost_cropped`
- :ref:`spkg_cysignals`
- :ref:`spkg_cython`
- :ref:`spkg_eclib`
- :ref:`spkg_ecm`
- :ref:`spkg_flint`
- :ref:`spkg_fpylll`
- :ref:`spkg_gap`
- :ref:`spkg_givaro`
- :ref:`spkg_glpk`
- :ref:`spkg_gmpy2`
- :ref:`spkg_gsl`
- :ref:`spkg_iml`
- :ref:`spkg_importlib_metadata`
- :ref:`spkg_importlib_resources`
- :ref:`spkg_ipykernel`
- :ref:`spkg_ipython`
- :ref:`spkg_ipywidgets`
- :ref:`spkg_jinja2`
- :ref:`spkg_jupyter_client`
- :ref:`spkg_jupyter_core`
- :ref:`spkg_lcalc`
- :ref:`spkg_libbraiding`
- :ref:`spkg_libgd`
- :ref:`spkg_libhomfly`
- :ref:`spkg_libpng`
- :ref:`spkg_linbox`
- :ref:`spkg_lrcalc_python`
- :ref:`spkg_m4ri`
- :ref:`spkg_m4rie`
- :ref:`spkg_matplotlib`
- :ref:`spkg_memory_allocator`
- :ref:`spkg_mpc`
- :ref:`spkg_mpfi`
- :ref:`spkg_mpfr`
- :ref:`spkg_networkx`
- :ref:`spkg_ntl`
- :ref:`spkg_numpy`
- :ref:`spkg_pari`
- :ref:`spkg_pexpect`
- :ref:`spkg_pillow`
- :ref:`spkg_pip`
- :ref:`spkg_pkgconfig`
- :ref:`spkg_ppl`
- :ref:`spkg_pplpy`
- :ref:`spkg_primecount`
- :ref:`spkg_primecountpy`
- :ref:`spkg_primesieve`
- :ref:`spkg_ptyprocess`
- :ref:`spkg_pythran`
- :ref:`spkg_requests`
- :ref:`spkg_rw`
- :ref:`spkg_sage_conf`
- :ref:`spkg_sage_setup`
- :ref:`spkg_sagemath_brial`
- :ref:`spkg_sagemath_categories`
- :ref:`spkg_sagemath_cddlib`
- :ref:`spkg_sagemath_combinat`
- :ref:`spkg_sagemath_eclib`
- :ref:`spkg_sagemath_environment`
- :ref:`spkg_sagemath_flint`
- :ref:`spkg_sagemath_gap`
- :ref:`spkg_sagemath_gap_pkg_ctbllib_data`
- :ref:`spkg_sagemath_gap_pkg_irredsol_data`
- :ref:`spkg_sagemath_gap_pkg_tomlib_data`
- :ref:`spkg_sagemath_gap_pkg_transgrp_data`
- :ref:`spkg_sagemath_giac`
- :ref:`spkg_sagemath_glpk`
- :ref:`spkg_sagemath_graphs`
- :ref:`spkg_sagemath_groups`
- :ref:`spkg_sagemath_homfly`
- :ref:`spkg_sagemath_lcalc`
- :ref:`spkg_sagemath_libbraiding`
- :ref:`spkg_sagemath_libecm`
- :ref:`spkg_sagemath_linbox`
- :ref:`spkg_sagemath_modules`
- :ref:`spkg_sagemath_nauty`
- :ref:`spkg_sagemath_ntl`
- :ref:`spkg_sagemath_objects`
- :ref:`spkg_sagemath_palp`
- :ref:`spkg_sagemath_pari`
- :ref:`spkg_sagemath_pari_galdata`
- :ref:`spkg_sagemath_pari_seadata_small`
- :ref:`spkg_sagemath_planarity`
- :ref:`spkg_sagemath_plot`
- :ref:`spkg_sagemath_polyhedra`
- :ref:`spkg_sagemath_repl`
- :ref:`spkg_sagemath_schemes`
- :ref:`spkg_sagemath_singular`
- :ref:`spkg_sagemath_tachyon`
- :ref:`spkg_scipy`
- :ref:`spkg_setuptools`
- :ref:`spkg_singular`
- :ref:`spkg_six`
- :ref:`spkg_sphinx`
- :ref:`spkg_symmetrica`
- :ref:`spkg_typing_extensions`

Version Information
-------------------

package-version.txt::

    10.6.29

version_requirements.txt::

    passagemath-standard-no-symbolics ~= 10.6.29.0

Installation commands
---------------------

.. tab:: PyPI:

   .. CODE-BLOCK:: bash

       $ pip install passagemath-standard-no-symbolics~=10.6.29.0

.. tab:: Sage distribution:

   .. CODE-BLOCK:: bash

       $ sage -i sagemath_standard_no_symbolics


However, these system packages will not be used for building Sage
because ``spkg-configure.m4`` has not been written for this package;
see :issue:`27330` for more information.
